# frozen_string_literal: true
require 'ext/string'
require 'steamd/version'
require 'steamd/generator'
require 'steamd/generator/ruby/steam_serializable'

# Provide Ruby access to the Steam Language
module Steamd
  # Loads the full Steam Language
  def self.load_language
    require 'steamd/generated/emsg'
    require 'steamd/generated/eresult'
    require 'steamd/generated/gamecoordinator'
    require 'steamd/generated/header'
    require 'steamd/generated/steammsg'
  end

  # Provides the absolute directory to the grammar directory. The grammar
  # directory holds the Treetop grammars.
  #
  # @return [String] the absolute path to the grammar directory
  def self.grammar_dir
    "#{root}/grammar"
  end

  # Provides the absolute directory to the language directory. The language
  # directory holds the Steam Language.
  #
  # @return [String] the absolute path to the language directory
  def self.language_dir
    "#{root}/language"
  end

  # Provides the absolute directory to the root directory
  #
  # @return [String] the absolute path to the root directory
  def self.root
    File.expand_path(File.join(__dir__, '..'))
  end
end
