# frozen_string_literal: true
module Steamd
  # Options that the CLI can take
  class CliOptions
    # Create a CliOptions object
    #
    # @example Using CliOptions
    #   opts = CliOptions.new(ouput: './')
    #
    # @param opts [Hash] options hash
    # @option opts [String] :output the output directory
    # @option opts [String] :input the output directory
    def initialize(opts = {})
      @options = opts
      @output  = opts[:output]
      @input   = opts[:input]
      self
    end

    # Returns the absolute path of the input directory specified by the
    # cli.
    #
    # Throws an exception if the input is not a directory
    #
    # @example Getting the input path
    #   opts = CliOptions.new(input: '/some/dir')
    #   opts.input # => '/some/dir'
    def input
      o = if @input.nil?
            Steamd.language_dir
          else
            @input
          end

      raise 'input must be a directory' unless File.directory?(o)
      File.expand_path(o)
    end

    # Returns the absolute path of the output directory specified by the
    # cli.
    #
    # Throws an exception if the output is not a directory
    #
    # @example Getting the output path
    #   opts = CliOptions.new(output: '/some/dir')
    #   opts.output # => '/some/dir'
    def output
      o = if @output.nil?
            './lib/steamd'
          else
            @output
          end

      raise 'output must be a directory' unless File.directory?(o)
      File.expand_path(o)
    end
  end
end
