# frozen_string_literal: true
require 'steamd/generator/ruby/ruby'

module Steamd
  # Generates the steam language into specified code
  #
  # @example Generate Ruby code
  #   generator = CodeGenerator.new('/input/dir', 'output/dir')
  #   generator.generate
  class CodeGenerator
    def initialize(input, output)
      @input  = input
      @output = output
    end

    # Generates ruby code from the input, places the Ruby files
    # in the output
    def generate
      make_output_directory

      files.each do |file|
        File.write("#{@output}/#{File.basename(file, '.*')}.rb",
                   Steamd::Generator::Ruby.new(file).run)
      end
    end

    private

    # @api private
    def make_output_directory
      FileUtils.mkdir_p(@output)
    end

    # @api private
    def files
      Dir.glob("#{@input}/*.steamd").map do |file|
        File.open(File.expand_path(file))
      end
    end
  end
end
