# frozen_string_literal: true
module Steamd
  module Generator
    # Enum variable
    class EnumVariable
      attr_reader :name, :value, :flags
      def initialize(name, value, flags)
        @name = name
        @value = value
        @flags = flags
      end

      def name
        @name.underscore.upcase
      end

      def value
        if flags && @value.is_a?(String)
          @value
            .split('|')
            .map(&:strip)
            .map(&:underscore)
            .map(&:upcase)
            .join(' | ')
        else
          @value
        end
      end
    end

    # Represents an Enum from the Generator
    class GeneratedEnum
      def initialize(enum)
        @enum = enum
      end

      # Type of Enum
      def type
        @enum[:type]
      end

      # Entries of enum
      def variables
        @enum[:variables].map do |v|
          EnumVariable.new(v[:name], v[:value], @enum[:flags])
        end
      end

      # Name of enum
      def name
        @enum[:name]
      end

      # Binding for ERB
      def erb_binding
        binding
      end
    end
  end
end
