# frozen_string_literal: true
require 'steamd/generator/implementation'

# frozen_string_literal: true
module Steamd
  module Generator
    # Generates Ruby code
    class Ruby
      include Implementation

      # Generate Ruby code for the Steam Language
      def generate
        classes.each do |klass|
          append(erb(klass_template, klass))
        end

        imports.each do |import|
          append(erb(import_template, import))
        end

        enums.each do |enum|
          append(erb(enum_template, enum))
        end
      end

      private

      # @api private
      def import_template
        erb_file('import.erb').read
      end

      # @api private
      def enum_template
        erb_file('enum.erb').read
      end

      # @api private
      def klass_template
        erb_file('class.erb').read
      end

      # @api private
      def erb_file(file)
        File.open(File.expand_path("#{erb_template_root}/#{file}"))
      end

      # @api private
      def erb_template_root
        File.dirname(__FILE__)
      end
    end
  end
end
