
# frozen_string_literal: true
# Represents a Serialized var
class SerizableVariable
  attr_reader :name, :type, :size, :modifier, :modifier_size, :value
  attr_accessor :flag

  # Initialize a SteamSerializable from a hash
  def initialize(var)
    @name = var[:name]
    @value = var[:value]
    @modifier = var[:modifier]
    @modifier_size = var[:modifier_size]
    @type = Type.new(var[:type])
  end

  # Serialize the object
  def serialize
    if type.primitive?
      serialize_primitive
    elsif type.encodable?
      serialize_encodable
    else
      serialize_object
    end
  end

  # Serialize the object
  #
  # @param io [:read]
  def deserialize(io)
    @value = if type.primitive?
               deserialize_primitive(io)
             elsif type.encodable?
               deserialize_encodable(io)
             else
               deserialize_object(io)
             end
  end

  private

  # @api private
  def deserialize_object(io)
    type = Type.new(self.type.klass::DATA_TYPE)
    io.read(type.bytesize).unpack(type.bytedirective).first
  end

  # @api private
  def deserialize_encodable(io)
    raise NotImplementedError if flag.nil? || modifier_size.nil?
    type.klass.decode(io.read(flag.value))
  end

  # @api private
  def deserialize_primitive(io)
    io.read(type.bytesize).unpack(type.bytedirective).first
  end

  # @api private
  def serialize_object
    type = Type.new(self.type.klass::DATA_TYPE)
    [value].pack(type.bytedirective)
  end

  # @api private
  def serialize_encodable
    raise NotImplementedError unless value.respond_to?(:encode)
    value.encode
  end

  # @api private
  def serialize_primitive
    if flag
      [flag.value.encode.length].pack('<l')
    else
      [value].pack(type.bytedirective)
    end
  end

  # @api private
  def validate
    raise NotImplementedError unless @var[:size].nil?
  end
end
