# frozen_string_literal: true
# A parsed class statement
#
# @example A class
#   class Test { }
#
# Contains the variables, class name, type
class ClassStatement < Node
  # Returns the class object as a hash
  #
  # @return [Hash] hash representation of the class
  def to_hash
    {
      name: name,
      type: type,
      variables: variables
    }
  end

  # The name of the class
  def name
    class_name.text_value
  end

  # The class type
  #
  # ie class Test<EMsg::Blah> {}
  def type
    types = elements.select { |el| el.is_a?(ClassType) }
    type = types.first
    type&.value
  end

  # Returns a list of variables
  #
  # @return [Array] variables
  def variables
    declerations = [first_var] + other.elements.map(&:decleration)

    variables = declerations.select do |node|
      node.is_a?(Variable)
    end

    variables.map!(&:to_hash)
  end
end
