# frozen_string_literal: true
# Represents an Enum statement
#
# @example Enum Statement
#   enum Test { Invalid = 1; }
class EnumStatement < Node
  # The name of the enum
  #
  # @return [String]
  def name
    enum_name.text_value
  end

  # The type of the enum
  #
  # @return [String]
  def type
    enum_type.type.text_value if enum_type.respond_to?(:type)
  end

  # Returns true if this enum uses bitmask flags
  #
  # @return [Bool]
  def flags?
    type == 'flags'
  end

  # Returns a list of EnumVariable objects
  #
  # @return Array
  def variables
    declerations = [first_var] + other.elements.map(&:enum_decleration)

    variables = declerations.select do |node|
      node.is_a?(EnumVariable)
    end

    variables.map!(&:to_hash)
  end

  # Hash representation of this Enum
  def to_hash
    {
      name: name,
      type: type,
      flags: flags?,
      variables: variables
    }
  end
end
